summaryrefslogtreecommitdiffstats
path: root/device/bluetooth/bluetooth_gatt_notify_session_chromeos.cc
diff options
context:
space:
mode:
Diffstat (limited to 'device/bluetooth/bluetooth_gatt_notify_session_chromeos.cc')
-rw-r--r--device/bluetooth/bluetooth_gatt_notify_session_chromeos.cc20
1 files changed, 11 insertions, 9 deletions
diff --git a/device/bluetooth/bluetooth_gatt_notify_session_chromeos.cc b/device/bluetooth/bluetooth_gatt_notify_session_chromeos.cc
index ba7b843..02f7ed8 100644
--- a/device/bluetooth/bluetooth_gatt_notify_session_chromeos.cc
+++ b/device/bluetooth/bluetooth_gatt_notify_session_chromeos.cc
@@ -6,11 +6,11 @@
#include "base/bind.h"
#include "base/logging.h"
-#include "chromeos/dbus/dbus_thread_manager.h"
#include "device/bluetooth/bluetooth_adapter.h"
#include "device/bluetooth/bluetooth_device.h"
#include "device/bluetooth/bluetooth_gatt_service.h"
#include "device/bluetooth/bluetooth_remote_gatt_characteristic_chromeos.h"
+#include "device/bluetooth/dbus/bluez_dbus_manager.h"
namespace chromeos {
@@ -32,12 +32,13 @@ BluetoothGattNotifySessionChromeOS::BluetoothGattNotifySessionChromeOS(
DCHECK(!characteristic_id_.empty());
DCHECK(object_path_.IsValid());
- DBusThreadManager::Get()->GetBluetoothGattCharacteristicClient()->AddObserver(
- this);
+ bluez::BluezDBusManager::Get()
+ ->GetBluetoothGattCharacteristicClient()
+ ->AddObserver(this);
}
BluetoothGattNotifySessionChromeOS::~BluetoothGattNotifySessionChromeOS() {
- DBusThreadManager::Get()
+ bluez::BluezDBusManager::Get()
->GetBluetoothGattCharacteristicClient()
->RemoveObserver(this);
Stop(base::Bind(&base::DoNothing));
@@ -58,11 +59,12 @@ bool BluetoothGattNotifySessionChromeOS::IsActive() {
// actually active, since the characteristic might have stopped sending
// notifications yet this method was called before we processed the
// observer event (e.g. because somebody else called this method in their
// BluetoothGattCharacteristicClient::Observer implementation, which was
// called before ours). Check the client to see if notifications are still
// being sent.
- BluetoothGattCharacteristicClient::Properties* properties =
- DBusThreadManager::Get()
+ bluez::BluetoothGattCharacteristicClient::Properties* properties =
+ bluez::BluezDBusManager::Get()
->GetBluetoothGattCharacteristicClient()
->GetProperties(object_path_);
if (!properties || !properties->notifying.value())
@@ -115,8 +117,8 @@ void BluetoothGattNotifySessionChromeOS::GattCharacteristicPropertyChanged(
if (!active_)
return;
- BluetoothGattCharacteristicClient::Properties* properties =
- DBusThreadManager::Get()
+ bluez::BluetoothGattCharacteristicClient::Properties* properties =
+ bluez::BluezDBusManager::Get()
->GetBluetoothGattCharacteristicClient()
->GetProperties(object_path_);
if (!properties) {
@@ -58,11 +59,12 @@ bool BluetoothGattNotifySessionChromeOS::IsActive() {
// notifications yet this method was called before we processed the
// observer event (e.g. because somebody else called this method in their
- // BluetoothGattCharacteristicClient::Observer implementation, which was
+ // bluez::BluetoothGattCharacteristicClient::Observer implementation, which
+ // was
// called before ours). Check the client to see if notifications are still
// being sent.